<?php
if ( ! defined( 'ABSPATH' ) ) {
    exit;
}

class IWJ_Candidate_Listing {

    public static function get_data_filters($convert_slug_to_id = true){
        static $data_filters = null;
        if(is_null($data_filters)){
            $data_filters = array('post_type' => 'iwj_candidate');

            if ( isset( $_REQUEST['url']) ) {
                $data_filters['url'] = $_REQUEST['url'];
            }

            if (isset($_REQUEST['keyword']) && $_REQUEST['keyword']) {
                $data_filters['keyword'] = sanitize_text_field($_REQUEST['keyword']);
            }

            $job_taxs = iwj_get_candidate_taxonomies();

            foreach ($job_taxs as $job_tax_key) {
                if ( isset($_REQUEST[$job_tax_key]) && $_REQUEST[$job_tax_key] ) {
                    $term_ids = $convert_slug_to_id  ? (array)iwj_convert_tax_slug_to_id($job_tax_key, $_REQUEST[$job_tax_key]) : (array)$_REQUEST[$job_tax_key];
                    if (isset($data_filters[$job_tax_key])) {
                        $data_filters[$job_tax_key] = array_merge($data_filters[$job_tax_key], $term_ids);
                    } else {
                        $data_filters[$job_tax_key] = $term_ids;
                    }
                }

                if (isset($data_filters[$job_tax_key])) {
                    $data_filters[$job_tax_key] = array_unique($data_filters[$job_tax_key]);
                }
            }

            if (isset($_REQUEST['order']) && $_REQUEST['order']) {
                $data_filters['order'] = $_REQUEST['order'];
            }

            $data_filters['paged'] = isset($_REQUEST['paged']) ? ($_REQUEST['paged'])  : 1;

            if(get_query_var('page') > 1){
                $data_filters['paged'] = get_query_var('page');
            }

            $data_filters = apply_filters('iwj_get_data_filters_candidate', $data_filters);

        }

        return $data_filters;
    }

    /**
     * Count candidate in taxonomy when ajax load
     *
     * @return array
     */
    public static function count_candidates_in_taxonomy( $data_filters ) {

        $result = iwj_count_item_by_taxonomy($data_filters);

        $data = array();

        if ($result) {
            foreach ($result as $k => $v) {
                $data[] = array('idx' => $k, 'name' => $v->name, 'val' => $v->total_post);
            }
        }

        return $data;
    }

    public static function get_query_candidates( $data_filters ) {
        $args = array(
            'post_type' 	 => 'iwj_candidate',
            'post_status' => array('publish'),
        );

        $filter_taxonomy = false;
        $args['tax_query'] = array(
            'relation' => 'AND'
        );

        $job_taxs = iwj_get_candidate_taxonomies();
        foreach ($job_taxs as $tax) {

            if ( isset($data_filters[$tax]) && is_array($data_filters[$tax]) && $data_filters[$tax] ) {
                $filter_taxonomy = true;
                $args['tax_query'][] = array(
                    'taxonomy' => $tax,
                    'field'    => 'term_id',
                    'terms'    => $data_filters[$tax]
                );
            }
        }

        if (isset($data_filters['order']) && $data_filters['order']) {
            $order_by = $data_filters['order'];

            if ($order_by == 'date') {
                $args['orderby'] = 'date';
                $args['order'] = 'DESC';
            } elseif ($order_by == 'name') {
                $args['orderby'] = 'title';
                $args['order'] = 'ASC';
            } else {
                $args['orderby'] = 'date';
                $args['order'] = 'DESC';
            }
        }

        $args['paged'] = isset($data_filters['paged']) ? (int) $data_filters['paged'] : 1;

        if ( !$filter_taxonomy ) {
            unset($args['tax_query']);
        }
	    // --- meta data ---
	    $args['meta_query'] = array(
		    'relation' => 'OR',
		    array(
			    'key' => IWJ_PREFIX . 'public_account',
			    'compare' => 'NOT EXISTS' // doesn't work
		    ),
		    array(
			    'key'     => IWJ_PREFIX . 'public_account',
			    'value'   => 1,
			    'compare' => '='
		    )
	    );
	    // --- end meta data ---

        $args['posts_per_page'] = iwj_option('candidates_per_page', get_option('posts_per_page', 20));
        if(isset($data_filters['posts_per_page']) && $data_filters['posts_per_page']){
            $args['posts_per_page'] = $data_filters['posts_per_page'];
        }

        add_filter('posts_where', array( __CLASS__, '_candidate_listing_where' ), 10, 2);
        add_filter('posts_join', array( __CLASS__, '_candidate_listing_join' ), 10, 2);

        $args = apply_filters('iwj_hook_ajax_args_query_listing_candidate', $args);

        $query = new WP_Query( $args );

        remove_filter('posts_where', array( __CLASS__, '_candidate_listing_where' ));
        remove_filter('posts_join', array( __CLASS__, '_candidate_listing_join' ));

        $query = apply_filters('iwj_hook_ajax_query_listing_candidate', $query);

        return $query;
    }

    public static function _candidate_listing_where($where, $query){
        $data_filters = self::get_data_filters();
        if(isset($data_filters['keyword']) && $data_filters['keyword']){
            global $wpdb;
            $keywords = explode(" ", $data_filters['keyword']);
            $keywords = array_filter(array_map('trim', $keywords));
            $keyword_where = array();
            foreach($keywords as $keyword){
                $keyword_where[] = "{$wpdb->posts}.post_title LIKE '%".$wpdb->_escape($keyword)."%'";
                $keyword_where[] = "{$wpdb->posts}.post_content LIKE '%".$wpdb->_escape($keyword)."%'";
                $keyword_where[] = "skill_pm.meta_value LIKE '%".$wpdb->_escape($keyword)."%'";
                $keyword_where[] = "skill_terms.`name` LIKE '%".$wpdb->_escape($data_filters['keyword'])."%'";
            }
            $where .= " AND (".implode(" OR ", $keyword_where).")";
        }

        return $where;
    }

    public static function _candidate_listing_join($join, $query){
        $data_filters = self::get_data_filters();
        if(isset($data_filters['keyword']) && $data_filters['keyword']){
            global $wpdb;
            $join .= " LEFT JOIN $wpdb->postmeta as skill_pm ON ($wpdb->posts.ID = skill_pm.post_id AND skill_pm.meta_key = '_iwj_skill_showcase')";

            $join .= " LEFT JOIN $wpdb->term_relationships as skill_term_relationships ON $wpdb->posts.ID = skill_term_relationships.object_id 
             LEFT JOIN $wpdb->term_taxonomy AS skill_term_taxonomy ON (skill_term_relationships.term_taxonomy_id = skill_term_taxonomy.term_taxonomy_id AND skill_term_taxonomy.taxonomy = 'iwj_skill')
             LEFT JOIN $wpdb->terms AS skill_terms ON skill_terms.term_id = skill_term_taxonomy.term_taxonomy_id";

        }

        return $join;
    }

    /**
     * Add url params when filter ajax load
     *
     * @return string
     */
    public static function get_request_url( $data_filters ) {

        $url = '';
        if ( isset($data_filters['url']) ) {
            $url = $data_filters['url'];
        }

        $add_query_arr = array();

        if (isset($data_filters['feed']) && $data_filters['feed']) {
            $add_query_arr['feed'] = $data_filters['feed'];
        }

        $taxonomy_names = iwj_get_candidate_taxonomies();

        foreach($taxonomy_names as $taxonomy_name){
            if (isset($data_filters[$taxonomy_name]) && $data_filters[$taxonomy_name]) {
                $terms = (array)iwj_convert_tax_id_to_slug($taxonomy_name, $data_filters[$taxonomy_name]);
                if($terms){
                    if($terms){
                        if(count($terms) > 1){
                            foreach($terms as $term){
                                $add_query_arr[$taxonomy_name.'%5B%5D='.$term] = '';
                            }
                        }else{
                            $add_query_arr[$taxonomy_name.'='.$terms[0]] = '';
                        }
                    }
                }
            }
        }

        if (isset($data_filters['paged']) && ($data_filters['paged']) > 1) {
            $add_query_arr['page'] = (int) $data_filters['paged'];
        }

        if (isset($data_filters['order']) && $data_filters['order']) {
            $add_query_arr['order'] = $data_filters['order'];
        }

        if (isset($data_filters['keyword']) && $data_filters['keyword']) {
            $add_query_arr['keyword'] = $data_filters['keyword'];
        }

        $add_query_arr = apply_filters('iwj_candidate_url_request_args', $add_query_arr, $data_filters);

        $url = add_query_arg( $add_query_arr, $url );

        return $url;
    }

    public static function get_feed_url($filters = null){
        if(is_null($filters)){
            $filters = self::get_data_filters();
        }

        $filters['url'] = home_url('/');
        $filters = array('feed'=>'candidate_feed') + $filters;

        return self::get_request_url($filters);
    }
}